/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.task.field;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.field.type.ActivityFieldChildFactory;
import nl.cloudfarming.client.geoviewer.MapOnlyNodeProvider;
import nl.cloudfarming.client.model.ItemIdType;
import nl.cloudfarming.client.task.ExportableTask;
import org.openide.nodes.Node;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 * @author Maciek Dulkiewicz
 */
public class FieldTask extends ExportableTask {

    public static final double MIN_WORK_WIDTH = 5;
    private double workWidth = MIN_WORK_WIDTH;
    public static final String MIME_TYPE = "application/x-agrosense-field-task";
    public static final String EXT = "ftk";
    public static final String PROP_TREATMENTZONE_VALUE = "treatmentZoneValue";

    public FieldTask(ActivityField activityField) {
        super(activityField.getURI(), new Class[]{ActivityField.class}, ItemIdType.FTK);
        ActivityField copy = new ActivityField(activityField);
        getContext().addItem(copy);
        setName(activityField.getName());
        ic.add(new TreatmentZoneNodeProvider());
    }

    @Override
    public double getWorkWidth() {
        return workWidth;
    }

    public void setWorkWidth(double workWidth) {
        double oldWorkWidth = this.workWidth;
        this.workWidth = workWidth;
        setRegenerateGrid(true);
        getPropertyChangeSupport().firePropertyChange(ExportableTask.PROP_WORK_WIDTH, oldWorkWidth, this.workWidth);
    }

    public void fireExternalPropertyChange(String eventName, Object oldValue, Object newValue) {
        getPropertyChangeSupport().firePropertyChange(eventName, oldValue, newValue);
    }

    public class TreatmentZoneNodeProvider implements MapOnlyNodeProvider, Serializable {

        @Override
        public Node[] getMapOnlyNodes() {
            ActivityField activityField = getLookup().lookup(ActivityField.class);
            ActivityFieldChildFactory childFactory = new ActivityFieldChildFactory(activityField);
            List<Node> nodes = new ArrayList<>();
            for (TreatmentZone treatmentZone : activityField.getTreatmentZones()) {
                nodes.add(childFactory.createNodeForKey(treatmentZone));
            }
            return nodes.toArray(new Node[nodes.size()]);
        }
    }
}
