/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.task.field;

import org.openide.util.ImageUtilities;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class FieldTaskOverviewPanel extends javax.swing.JPanel {

    /**
     * Creates new form FieldTaskOverviewPanel
     */
    public FieldTaskOverviewPanel() {
        initComponents();
    }

    public void setTask(FieldTask task) {
        taskStatePanel1.setTask(task);
        workWidthPanel1.setTask(task);
        addActivityFieldPanel(task);
        taskExportButton1.setTask(task);
    }

    /**
     * Add an ActivityFieldPanel to the TaskContentPanel JTabbedPanel. The
     * ActivityFieldPanel handles it's own content but needs a task to do so.
     * The newly added ActivityFieldPanel also needs a pretty icon that is
     * displayed on it's own tab in the TaskContentPane
     *
     * @param task Task containing ActivityField objects
     */
    private void addActivityFieldPanel(FieldTask task) {
        taskContentPanel.add(new FieldTaskPanel(task));
        //components in the JTabbedPanel are accessed using an index
        //the index of the newly added component is the componentCount of the 
        //TaskContentPanel minus 1
        int newComponentIndex = taskContentPanel.getComponentCount() - 1;
        taskContentPanel.setIconAt(newComponentIndex, ImageUtilities.loadImageIcon(FieldTaskPanel.TAB_ICON_RESOURCE_PATH, false));
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        taskStatePanel1 = new nl.cloudfarming.client.task.windows.TaskStatePanel();
        taskContentPanel = new javax.swing.JTabbedPane();
        workWidthPanel1 = new nl.cloudfarming.client.task.field.WorkWidthPanel();
        taskExportButton1 = new nl.cloudfarming.client.task.field.TaskExportButton();

        taskContentPanel.setBackground(java.awt.Color.white);
        taskContentPanel.setBorder(javax.swing.BorderFactory.createTitledBorder(org.openide.util.NbBundle.getMessage(FieldTaskOverviewPanel.class, "FieldTaskOverviewPanel.taskContentPanel.border.title"))); // NOI18N

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(taskStatePanel1, javax.swing.GroupLayout.PREFERRED_SIZE, 161, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(workWidthPanel1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addGroup(layout.createSequentialGroup()
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                            .addComponent(taskExportButton1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(taskContentPanel, javax.swing.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE))
                        .addGap(9, 9, 9)))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(taskStatePanel1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(workWidthPanel1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(taskContentPanel, javax.swing.GroupLayout.DEFAULT_SIZE, 358, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(taskExportButton1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JTabbedPane taskContentPanel;
    private nl.cloudfarming.client.task.field.TaskExportButton taskExportButton1;
    private nl.cloudfarming.client.task.windows.TaskStatePanel taskStatePanel1;
    private nl.cloudfarming.client.task.field.WorkWidthPanel workWidthPanel1;
    // End of variables declaration//GEN-END:variables
}
