/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.task.field;

import java.util.List;
import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.model.Entity;
import nl.cloudfarming.client.util.swing.beanbinding.PositiveDoubleValidator;
import org.jdesktop.beansbinding.AutoBinding;
import org.jdesktop.beansbinding.BeanProperty;
import org.jdesktop.beansbinding.Converter;
import org.jdesktop.swingbinding.JTableBinding;
import org.jdesktop.swingbinding.JTableBinding.ColumnBinding;
import org.jdesktop.swingbinding.SwingBindings;
import org.openide.util.LookupEvent;
import org.openide.util.LookupListener;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 * @author Wytse Visser
 * @author Maciek Dulkiewicz
 */
public class FieldTaskPanel extends javax.swing.JPanel implements LookupListener, TableModelListener {

    private JTableBinding binding = null;
    public static final String TAB_ICON_RESOURCE_PATH = "nl/cloudfarming/client/task/field/treatmentzone.png";
    private FieldTask task;

    /**
     * Creates new form ActivityFieldPanel
     */
    public FieldTaskPanel() {
        initComponents();
    }

    public FieldTaskPanel(FieldTask task) {
        this();
        setTask(task);
        treatmentZoneTable.getModel().addTableModelListener(this);
    }

    public final void setTask(FieldTask task) {
        this.task = task;
        task.getLookup().lookupResult(Entity.class).addLookupListener(this);
        if (binding != null) {
            binding.unbind();
        }
        ActivityField field = task.getLookup().lookup(ActivityField.class);
        List<TreatmentZone> treatmentZones = field.getTreatmentZones();
        if (!treatmentZones.isEmpty()) {
            binding = SwingBindings.createJTableBinding(
                    AutoBinding.UpdateStrategy.READ,
                    treatmentZones,
                    treatmentZoneTable);

            BeanProperty nameProperty = BeanProperty.create("name");
            ColumnBinding nameBinding = binding.addColumnBinding(nameProperty);
            nameBinding.setColumnName("Name");
            nameBinding.setEditable(false);

            BeanProperty valueProperty = BeanProperty.create("value");
            ColumnBinding columnBinding = binding.addColumnBinding(valueProperty);
            columnBinding.setColumnName("Value");
            columnBinding.setConverter(new StringToDoubleConverter());
            columnBinding.setValidator(new PositiveDoubleValidator());

            binding.bind();
        }
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        arrayList1 = new java.util.ArrayList();
        jScrollPane2 = new javax.swing.JScrollPane();
        treatmentZoneTable = new javax.swing.JTable();

        jScrollPane2.setViewportView(treatmentZoneTable);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jScrollPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 375, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jScrollPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 275, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private java.util.ArrayList arrayList1;
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JTable treatmentZoneTable;
    // End of variables declaration//GEN-END:variables

    @Override
    public void resultChanged(LookupEvent ev) {
//        updateTableValues();
    }

    @Override
    public void tableChanged(TableModelEvent e) {
        task.setRegenerateGrid(true);
        task.fireExternalPropertyChange(FieldTask.PROP_TREATMENTZONE_VALUE, null, null);
    }

    private class StringToDoubleConverter extends Converter<Double, String> {

        @Override
        public String convertForward(Double t) {
            return t + "";
        }

        @Override
        public Double convertReverse(String s) {
            Double d = Double.parseDouble(s);
            if(d == -0.0) {
                d = 0.0;
            }
            return d;
        }
        
    }
}
