/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.task.field;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.HashMap;
import java.util.Map;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.task.Task;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * Top component which displays something.
 */
@MultiViewElement.Registration(displayName = "#FieldTaskVisualElement_display_name",
iconBase = "nl/cloudfarming/client/task/field/to_do_list_checked_1.png",
mimeType = FieldTask.MIME_TYPE,
preferredID = "FieldTaskVisualElement",
position = 100,
persistenceType = TopComponent.PERSISTENCE_NEVER)
@Messages({
    "FieldTaskVisualElement_display_name=Task Context",
    "CTL_FieldTaskAction=FieldTask",
    "CTL_FieldTaskTopComponent=FieldTask Window",
    "HINT_FieldTaskTopComponent=This is a FieldTask window"
})
public final class FieldTaskVisualElement extends TopComponent implements MultiViewElement, PropertyChangeListener {

    private static final String TASK_ICON_PATH = "nl/cloudfarming/client/task/field/task32.png";
    private static final Map<FieldTask, FieldTaskVisualElement> OVERVIEW_FOR_TASK_MAP = new HashMap<>();
    private final FieldTask fieldTask;
    private FieldTaskOverviewPanel panel;
    private ASBodyPanel panelDecorator;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private Lookup lookup;

    /**
     * We need a constructor with a lookup for a MultiViewElement but we also
     * need to task in order to initialize the underlying panels. This
     * constructor accepts a lookup and uses the passed lookup to find an
     * ExportableTaskCapability object from which it can extract a task.
     *
     * @param lookup
     */
    public FieldTaskVisualElement(Lookup lookup) {
        this((FieldTask) lookup.lookup(FieldTask.class));
        this.lookup = lookup;
    }

    public FieldTaskVisualElement(FieldTask fieldTask) {
        this.fieldTask = fieldTask;
        panel = new FieldTaskOverviewPanel();
        panel.setTask(fieldTask);

        panelDecorator = new ASBodyPanel(panel);
        panelDecorator.setTitle(fieldTask.getName());
        panelDecorator.setIcon(ImageUtilities.loadImageIcon(TASK_ICON_PATH, true));
        setLayout(new BorderLayout());
        add(panelDecorator);

        setName(fieldTask.getName());
        setToolTipText(Bundle.HINT_FieldTaskTopComponent());
        this.fieldTask.addPropertyChangeListener(this);
    }

    public static FieldTaskVisualElement findInstance(FieldTask task) {
        FieldTaskVisualElement topComponent = OVERVIEW_FOR_TASK_MAP.get(task);
        if (topComponent == null) {
            topComponent = new FieldTaskVisualElement(task);
            OVERVIEW_FOR_TASK_MAP.put(task, topComponent);
        }
        return topComponent;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
                layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGap(0, 400, Short.MAX_VALUE));
        layout.setVerticalGroup(
                layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGap(0, 300, Short.MAX_VALUE));
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
    @Override
    public void componentOpened() {
        // TODO add custom code on component opening
    }

    @Override
    public void componentClosed() {
    }

    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
        // TODO store your settings
    }

    void readProperties(java.util.Properties p) {
        String version = p.getProperty("version");
        // TODO read your settings according to their version
    }

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    public void updateName() {
        if (callback != null) {
            String name = fieldTask.getName();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if (evt.getPropertyName().equalsIgnoreCase(Task.PROP_NAME)) {
            updateName();
        }
    }

    @Override
    public int getPersistenceType() {
        return super.getPersistenceType();
    }
}
