/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.field;

import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JSpinner.DefaultEditor;
import javax.swing.SpinnerListModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class WorkWidthPanel extends javax.swing.JPanel implements ChangeListener {

    //String values are used because an array of double values is not displayed
    //properly by the spinner. String values are used that are later converted
    //to double values
    private static final String MIN_WORK_WIDTH = Double.toString(FieldTask.MIN_WORK_WIDTH);
    private static final String[] DEFAULT_WORK_WIDTH_VALUES = {MIN_WORK_WIDTH, "10.0", "20.0", "25.0"};
    private static final SpinnerListModel workWidthSpinnerModel = new SpinnerListModel(Arrays.asList(DEFAULT_WORK_WIDTH_VALUES));
    private FieldTask task;
    private static final Logger LOGGER = Logger.getLogger(WorkWidthPanel.class.getCanonicalName());

    /**
     * Creates new form WorkWidthPanel
     */
    public WorkWidthPanel() {
        initComponents();

        //disable editing the text field of the spinner
        ((DefaultEditor) workWidthSpinner.getEditor()).getTextField().setEditable(false);

        workWidthSpinner.setModel(workWidthSpinnerModel);
        workWidthSpinner.addChangeListener(this);
    }

    public void setTask(FieldTask task) {
        this.task = task;
        setSpinnerValueToTaskWorkWidth();
    }

    protected void setSpinnerValueToTaskWorkWidth() {
        String workWidth = Double.toString(task.getWorkWidth());
        if (!workWidthSpinnerModel.getList().contains(workWidth)) {
            LOGGER.log(Level.WARNING, "Work width spinner does not contain work width value of task {0}", workWidth);
        } else {
            workWidthSpinner.setValue(workWidth);
        }
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        workWidthLabel = new javax.swing.JLabel();
        workWidthMeasurementLabel = new javax.swing.JLabel();
        workWidthSpinner = new javax.swing.JSpinner();

        setBackground(java.awt.Color.white);

        workWidthLabel.setText(org.openide.util.NbBundle.getMessage(WorkWidthPanel.class, "WorkWidthPanel.workWidthLabel.text")); // NOI18N

        workWidthMeasurementLabel.setText(org.openide.util.NbBundle.getMessage(WorkWidthPanel.class, "WorkWidthPanel.workWidthMeasurementLabel.text")); // NOI18N

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(workWidthLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(workWidthSpinner, javax.swing.GroupLayout.DEFAULT_SIZE, 72, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(workWidthMeasurementLabel)
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                .addComponent(workWidthLabel)
                .addComponent(workWidthSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addComponent(workWidthMeasurementLabel))
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel workWidthLabel;
    private javax.swing.JLabel workWidthMeasurementLabel;
    private javax.swing.JSpinner workWidthSpinner;
    // End of variables declaration//GEN-END:variables

    /**
     * When the value of the spinner changes, update the work width value of the
     * task contained by this panel.
     *
     * @param e event fired by the workWidthSpinner
     */
    @Override
    public void stateChanged(ChangeEvent e) {
        task.setWorkWidth(getWorkWidthValue());
    }

    protected double getWorkWidthValue() {
        String spinnerStringValue = (String) workWidthSpinner.getValue();
        return Double.valueOf(spinnerStringValue);
    }
}
