/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.field.tree;

import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.io.IOException;
import java.io.Serializable;
import java.util.Arrays;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.task.field.FieldTask;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.nodes.NodeTransfer;
import org.openide.util.ImageUtilities;
import org.openide.util.Utilities;

/**
 *
 * @author Maciek Dulkiewicz
 */
public class FieldTaskNode extends FilterNode implements Serializable {

    private static final String ICON_PATH = "nl/cloudfarming/client/task/field/to_do_list_checked_1.png";
    private static final String EXPORTABLE_TASK_ACTION_PATH = "Actions/ExportableTask";
    private FieldTask task;
    private Node original;

    public FieldTaskNode(Node original, FieldTask task) {
        super(original, Children.LEAF);
        this.task = task;
        this.original = original;
        disableDelegation(DELEGATE_SET_NAME);
        disableDelegation(DELEGATE_GET_NAME);
    }

    @Override
    public void setName(String name) {
        task.setName(name);
        original.setDisplayName(name);
    }

    @Override
    public String getName() {
        return task.getName();
    }

    @Override
    public String getDisplayName() {
        return task.getName();
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(ICON_PATH);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    @Override
    public Action[] getActions(boolean context) {
        List<Action> actions = (List<Action>) Utilities.actionsForPath(EXPORTABLE_TASK_ACTION_PATH);
        actions.addAll(Arrays.asList(super.getActions(context)));
        return actions.toArray(new Action[0]);
    }

    @Override
    public Transferable clipboardCopy() throws IOException {
        return NodeTransfer.transferable(this, NodeTransfer.CLIPBOARD_COPY);
    }

    @Override
    public Transferable clipboardCut() throws IOException {
        return clipboardCopy();
    }

    @Override
    public Transferable drag() throws IOException {
        return clipboardCopy();
    }
}
